beamprofiler.iso.characterizing\_parameters.beam\_aspect\_ratio
===============================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: beam_aspect_ratio